@@ -142,9 +142,14 @@ class _TaggableManager(models.Manager):
     def _lookup_kwargs(self):
         return self.through.lookup_kwargs(self.instance)
 
+    def _remove_prefetched_objects(self):
+        prefetch_cache = getattr(self.instance, "_prefetched_objects_cache", None)
+        if prefetch_cache:
+            prefetch_cache.pop(self.prefetch_cache_name, None)
+
     @require_instance_manager
     def add(self, *tags, through_defaults=None, tag_kwargs=None, **kwargs):
-
+        self._remove_prefetched_objects()
         if tag_kwargs is None:
             tag_kwargs = {}
         db = router.db_for_write(self.through, instance=self.instance)
@@ -297,6 +302,7 @@ class _TaggableManager(models.Manager):
         if not tags:
             return
 
+        self._remove_prefetched_objects()
         db = router.db_for_write(self.through, instance=self.instance)
 
         qs = (
@@ -329,6 +335,7 @@ class _TaggableManager(models.Manager):
 
     @require_instance_manager
     def clear(self):
+        self._remove_prefetched_objects()
         db = router.db_for_write(self.through, instance=self.instance)
 
         signals.m2m_changed.send(
@@ -713,7 +720,7 @@ class TaggableManager(RelatedField):
 
     # this is required to handle a change in Django 4.0
     # https://docs.djangoproject.com/en/4.0/releases/4.0/#miscellaneous
-    # the signature of the (private) funtion was changed
+    # the signature of the (private) function was changed
     if django.VERSION < (4, 0):
         get_extra_restriction = _get_extra_restriction_legacy
     else:
